# grad-gpad :moyai: [![version](https://img.shields.io/github/release/acostapazo/gradgpad/all.svg)](https://github.com/acostapazo/gradgpad/releases) [![ci](https://github.com/acostapazo/gradgpad/workflows/ci/badge.svg)](https://github.com/acostapazo/gradgpad/actions) [![pypi](https://img.shields.io/pypi/dm/gradgpad)](https://pypi.org/project/gradgpad/)



Insert project description here

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://github.com/acostapazo/gradgpad/blob/master/notebooks/reproducible-research.ipynb)


## Table of Contents
- [Installation :computer:](#installation-computer)
- [Testing :white_check_mark:](#testing-white_check_mark)
- [Contact :mailbox_with_mail:](#contact-mailbox_with_mail)


## Installation :computer:

Use [lume :fire:](https://github.com/alice-biometrics/lume) to install dependencies:

Example:

```console
>> conda create -n myenv python=3.6
>> conda activate myenv
(myenv) >> pip install lume
(myenv) >> lume -install
```

## Testing :white_check_mark:

### Unit, Integration and Acceptance

```console
(myenv) >> lume -test
```


## Contact :mailbox_with_mail:

support@alicebiometrics.com

